
%global pkg_name OpenGLRaw
%global pkgver %{pkg_name}-%{version}

Name:           ghc-%{pkg_name}
Version:        3.3.4.1
Release:    1%{?dist}
Summary:        A raw binding for the OpenGL graphics system

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkgver}/%{pkgver}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkgver}/%{pkg_name}.cabal#/%{pkgver}.cabal

BuildRequires:  dos2unix
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-fixed-devel
BuildRequires:  ghc-half-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
%if %{with ghc_prof}
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-fixed-prof
BuildRequires:  ghc-half-prof
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-prof
%endif
BuildRequires:  libglvnd-devel

%description
OpenGLRaw is a raw Haskell binding for the OpenGL 4.6 graphics system and lots
of OpenGL extensions. It is basically a 1:1 mapping of OpenGL's C API, intended
as a basis for a nicer interface. OpenGLRaw offers access to all necessary
functions, tokens and types plus a general facility for loading extension
entries. The module hierarchy closely mirrors the naming structure of the
OpenGL extensions, making it easy to find the right module to import.
All API entries are loaded dynamically, so no special C header files are needed
for building this package. If an API entry is not found at runtime, a userError
is thrown.

OpenGL is the industry's most widely used and supported 2D and 3D graphics
application programming interface (API), incorporating a broad set of
rendering, texture mapping, special effects, and other powerful visualization
functions. For more information about OpenGL and its various extensions, please
see <http://www.opengl.org/> and <http://www.opengl.org/registry/>.


%package devel
Summary:        Haskell %{pkg_name} library development files
Provides:       %{name}-static = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}
%if %{defined ghc_version}
Requires:       ghc-compiler = %{ghc_version}
%endif
Requires:       %{name} = %{version}-%{release}
Requires:       libglvnd-devel

%description devel
This package provides the Haskell %{pkg_name} library development files.


%if %{with haddock}
%package doc
Summary:        Haskell %{pkg_name} library documentation
BuildArch:      noarch
Requires:       ghc-filesystem

%description doc
This package provides the Haskell %{pkg_name} library documentation.
%endif


%if %{with ghc_prof}
%package prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       %{name}-devel = %{version}-%{release}
Supplements:    (%{name}-devel and ghc-prof)

%description prof
This package provides the Haskell %{pkg_name} profiling library.
%endif


%prep
%setup -q -n %{pkgver}
dos2unix -k -n %{SOURCE1} %{pkg_name}.cabal


%build
%ghc_lib_build


%install
%ghc_lib_install


%files -f %{name}.files
%license LICENSE


%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md


%if %{with haddock}
%files doc -f %{name}-doc.files
%license LICENSE
%endif


%if %{with ghc_prof}
%files prof -f %{name}-prof.files
%endif


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.4.1-1
- initial build
